@@ -1363,7 +1363,8 @@ class SimulatedTemperingSimulation(MDSimulation):
         self.maxTemperature = maxTemperature
         self.numTemperatures = numTemperatures
         self.reportInterval = reportInterval
-        self.reportFile = os.path.join(self.cwd, reportFile)
+
+        self.reportFile = reportFile
 
         self._build_custom_forces()
 
@@ -1374,7 +1375,7 @@ class SimulatedTemperingSimulation(MDSimulation):
                                                   minTemperature=self.minTemperature,
                                                   maxTemperature=self.maxTemperature,
                                                   reportInterval=self.reportInterval,
-                                                  reportFile=self.reportFile)
+                                                  reportFile=os.join(self.cwd,self.reportFile))
 
     def run(self, time):
         """
